@@ -138,6 +138,7 @@ class Connection(object):
 
         try:
             logger.debug('Issuing %s request to: %s' % (method, str(path)))
+            #logger.debug('Body: %s' % (body))
 
             flag = body is not None and '"password":' in repr(body)
 
@@ -148,6 +149,8 @@ class Connection(object):
             r = self.conn.request(method, path, data=body, params=params,
                                   headers=extra_headers, **kwargs)
 
+            logger.debug('Response for %s request to %s: %s, %d' %
+                         (method, str(path), r.status_code, len(r.content)))
             if flag:
                 self.set_debuglevel()
 
@@ -200,7 +203,7 @@ class Connection(object):
             return res
 
     def json_request(self, method, path, body=None,
-                     params=None, extra_headers=None):
+                     params=None, extra_headers=None, raw_response=False):
         """ Send a JSON request and receive JSON response. """
         if extra_headers:
             extra_headers = CaseInsensitiveDict(extra_headers)
@@ -217,10 +220,13 @@ class Connection(object):
         r = self._request(method, path, body, params, extra_headers)
         if r.status_code == 204 or len(r.content) == 0:
             return None  # no data
-        return r.json()
+
+        if raw_response:
+            return json.loads(r.text),r
+        return json.loads(r.text)
 
     def xml_request(self, method, path, body=None,
-                    params=None, extra_headers=None):
+                    params=None, extra_headers=None, raw_response=False):
         """Send an XML request to the host.
 
         The Content-Type and Accept headers are set to text/xml.  In addition,
@@ -239,14 +245,17 @@ class Connection(object):
         r = self._request(method, path, body, params, extra_headers)
 
         t = r.headers.get('Content-type', None)
-        if t != 'text/xml':
+        if t.find('text/xml') == -1:
             raise RvbdException('unexpected content type %s' % t)
 
-        tree = ElementTree.parse(r).getroot()
+        tree = ElementTree.fromstring(r.text.encode('ascii', 'ignore'))
 
         if self.DEBUG_MSG_BODY:
             logger.debug('Response body:\n' + str(tree) + '\n')
 
+        if raw_response:
+            return tree, r
+
         return tree
 
     def upload(self, path, data, method="POST", params=None, extra_headers=None):
