@@ -22,7 +22,7 @@ import re
 __all__ = [ 'ensure_timezone', 'force_to_utc', 'datetime_to_seconds', 
             'datetime_to_microseconds', 'datetime_to_nanoseconds',
             'usec_string_to_datetime', 'nsec_string_to_datetime',
-            'timedelta_total_seconds',
+            'timedelta_total_seconds', 'timedelta_str',
             'TimeParser', 'parse_timedelta', 'parse_range' ]
 
 
@@ -375,6 +375,62 @@ _timedelta_units = {
 
 _timedelta_re = re.compile("([0-9]*\.*[0-9]*) *([a-zA-Z]*)")
 
+def timedelta_str(td):
+    def pluralize(val, base, plural):
+        if val > 1:
+            return "%d %s" % (val, plural)
+        else:
+            return "%d %s" % (val, base)
+
+    if td.days > 0:
+        if td.seconds != 0 or td.microseconds != 0:
+            raise ValueError("Timedelta has too many components for pretty string: %s" % str(td))
+        if td.days % 7 == 0:
+            return pluralize(td.days / 7, "week", "weeks")
+        else:
+            return pluralize(td.days, "day", "days")
+    elif td.seconds > 0:
+        if td.microseconds != 0:
+            raise ValueError("Timedelta has too many components for pretty string: %s" % str(td))
+        if td.seconds % (60*60) == 0:
+            return pluralize(td.seconds / (60*60), "hour", "hours")
+        elif td.seconds % 60 == 0:
+            return pluralize(td.seconds / 60, "minute", "minutes")
+        else:
+            return pluralize(td.seconds, "second", "seconds")
+    else:
+        if td.microseconds % 1000 == 0:
+            return pluralize(td.microseconds / 1000, "millisecond", "milliseconds")
+        else:
+            return pluralize(td.microseconds, "microsecond", "microseconds")
+
+
+def round_time(dt=None, round_to=60, round_up=False, trim=False):
+    """Round a datetime object to any time laps in seconds
+    `dt` : datetime.datetime object, default now.
+    `round_to` : Closest number of seconds to round to, default 1 minute.
+    `round_up`: Default rounds down to nearest `round_to` interval,
+               True here will instead round up.
+    `trim`: Trim to nearest round_to value rather than rounding.
+    """
+    # ref http://stackoverflow.com/a/10854034/2157429
+    if dt is None:
+        dt = datetime.now()
+    dt = ensure_timezone(dt)
+
+    if trim:
+        rounded = (round_time(dt, round_to, False),
+                   round_time(dt, round_to, True))
+        return max(rounded) if max(rounded) <= dt else min(rounded)
+
+    seconds = (dt - dt.min.replace(tzinfo=dt.tzinfo)).seconds
+    if round_up:
+        rounding = (seconds + round_to / 2) // round_to * round_to
+    else:
+        rounding = (seconds - round_to / 2) // round_to * round_to
+    return dt + timedelta(0, rounding - seconds, -dt.microsecond)
+
+
 def parse_timedelta(s):
     """ Parse the string `s` representing some duration of time
     (e.g., `"3 seconds"` or `"1 week"`) and return a `datetime.timedelta`
@@ -397,7 +453,7 @@ def parse_timedelta(s):
         try:
             units = _timedelta_units[m.group(2)]
         except KeyError:
-            raise ValueError()
+            raise ValueError("Invalid timedelta units: %s" % m.group(2))
 
     return timedelta(seconds=units * float(val))
     
